@@ -1,18 +1,17 @@
 from typing import Any, List, Dict
 
 from dstf.core import Constraint, Schedule, Chunk
-from dstf.properties import ProcessedTimesProperty
 
 
 class NoSimultaneousExecutionConstraint(Constraint):
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        for tsk in schedule:
-            for chk in schedule[tsk]:
-                for node, ptime in chunk.proc_times.items():
-                    if (node in chk.proc_times
-                            and chunk.start_time < chk.start_time + chk.proc_times[node]
-                            and chunk.start_time + ptime > chk.start_time):
-                        return False
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        for node in chunk.proctimes:
+            if schedule.hasnode(node):
+                tree = schedule.node(node)
+                treenodes = tree.over(chunk.start_time, chunk.completion_time(node))
+
+                if len(treenodes) > 0:
+                    return False
 
         return True
 
@@ -21,10 +20,10 @@ class NoSimultaneousExecutionConstraint(Constraint):
 
 
 class NoMigrationConstraint(Constraint):
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        if chunk.task in schedule:
-            for chk in schedule[chunk.task]:
-                if not set(chk.proc_times).issuperset(chunk.proc_times):
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        if schedule.hastask(chunk.task):
+            for chk in schedule.task(chunk.task):
+                if not set(chk.proctimes).issuperset(chunk.proctimes):
                     return False
 
         return True
@@ -37,17 +36,20 @@ class ProcessingTimesConstraint(Constraint):
     def __init__(self, processing_times: Dict[Any, float]):
         self.processing_times = processing_times
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        prcs_times = schedule.get(ProcessedTimesProperty(chunk.task))
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        if schedule.hastask(chunk.task):
+            processed = {}
 
-        for node, ptime in chunk.proc_times.items():
-            if prcs_times is None:
-                rmn_ptime = self.processing_times[node]
-            else:
-                rmn_ptime = self.processing_times[node] - prcs_times[node]
+            for chk in schedule.task(chunk.task):
+                for node, ptime in chk.proctimes.items():
+                    if node in processed:
+                        processed[node] += ptime
+                    else:
+                        processed[node] = ptime
 
-            if ptime > rmn_ptime:
-                return False
+            for node, ptime in chunk.proctimes.items():
+                if ptime > self.processing_times[node] - processed[node]:
+                    return False
 
         return True
 
@@ -59,7 +61,7 @@ class ReleaseTimeConstraint(Constraint):
     def __init__(self, release_time: float):
         self.release_time = release_time
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
         return chunk.start_time >= self.release_time
 
     def get_error(self, schedule: "Schedule", chunk: "Chunk") -> str:
@@ -70,8 +72,8 @@ class DeadlineConstraint(Constraint):
     def __init__(self, deadline: float):
         self.deadline = deadline
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        for node, ptime in chunk.proc_times.items():
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        for node, ptime in chunk.proctimes.items():
             if chunk.start_time + ptime > self.deadline:
                 return False
 
@@ -85,8 +87,8 @@ class MultipurposeMachinesConstraint(Constraint):
     def __init__(self, compatible_nodes: List[Any]):
         self.compatible_nodes = compatible_nodes
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        for node in chunk.proc_times:
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        for node in chunk.proctimes:
             if node not in self.compatible_nodes:
                 return False
 
@@ -100,8 +102,8 @@ class ExecutionSizeConstraint(Constraint):
     def __init__(self, execution_size: int):
         self.execution_size = execution_size
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        return len(chunk.proc_times) == self.execution_size
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        return len(chunk.proctimes) == self.execution_size
 
     def get_error(self, schedule: "Schedule", chunk: "Chunk") -> str:
         return "'{}' task should be processed by {} nodes".format(chunk.task.name, self.execution_size)
@@ -111,8 +113,8 @@ class ExecutionNodesConstraint(Constraint):
     def __init__(self, execution_nodes: List[Any]):
         self.execution_nodes = execution_nodes
 
-    def is_valid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
-        return set(chunk.proc_times) == set(self.execution_nodes)
+    def isvalid(self, schedule: "Schedule", chunk: "Chunk") -> bool:
+        return set(chunk.proctimes) == set(self.execution_nodes)
 
     def get_error(self, schedule: "Schedule", chunk: "Chunk") -> str:
         return "'{}' task should be processed by {}".format(chunk.task.name, self.execution_nodes)
